unit Main;

interface

uses
  SysUtils, Windows, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Buttons, ExtCtrls, Menus, MRUList, ComCtrls;

type
  TMainForm = class(TForm)
    MainMenu: TMainMenu;
    FileNewItem: TMenuItem;
    FileOpenItem: TMenuItem;
    FileSaveItem: TMenuItem;
    FileSaveAsItem: TMenuItem;
    FileExitItem: TMenuItem;
    EditUndoItem: TMenuItem;
    EditCutItem: TMenuItem;
    EditCopyItem: TMenuItem;
    EditPasteItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    StatusLine: TStatusBar;
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    SpeedBar: TPanel;
    SpeedButton1: TSpeedButton;  { &Open... }
    SpeedButton2: TSpeedButton;  { &Save }
    SpeedButton3: TSpeedButton;  { &Undo }
    SpeedButton4: TSpeedButton;  { Cu&t }
    SpeedButton5: TSpeedButton;  { &Copy }
    SpeedButton6: TSpeedButton;  { &Paste }
    SpeedButton7: TSpeedButton;
    MRUFileList: TMRUFileList;
    FileExitSeparator: TMenuItem;  { E&xit }
    procedure FormCreate(Sender: TObject);
    procedure ShowHint(Sender: TObject);
    procedure FileNew(Sender: TObject);
    procedure FileOpen(Sender: TObject);
    procedure FileSave(Sender: TObject);
    procedure FileSaveAs(Sender: TObject);
    procedure FileExit(Sender: TObject);
    procedure EditUndo(Sender: TObject);
    procedure EditCut(Sender: TObject);
    procedure EditCopy(Sender: TObject);
    procedure EditPaste(Sender: TObject);
    procedure WindowTile(Sender: TObject);
    procedure WindowCascade(Sender: TObject);
    procedure WindowArrange(Sender: TObject);
    procedure MRUFileListMRUItemClick(Sender: TObject; AFilename: string);
  end;

var
  MainForm: TMainForm;

implementation

uses Child;

{$R *.DFM}

procedure TMainForm.FormCreate(Sender: TObject);
begin
  Application.OnHint := ShowHint;
end;

procedure TMainForm.ShowHint(Sender: TObject);
begin
  StatusLine.SimpleText := Application.Hint;
end;

procedure TMainForm.FileNew(Sender: TObject);
begin
  with TChildForm.Create(Self) do
    Caption := '[untitled]';
end;

procedure TMainForm.FileOpen(Sender: TObject);
begin
  if OpenDialog.Execute then
    with TChildForm.Create(Self) do begin
      Memo.Lines.LoadFromFile(OpenDialog.FileName);
      Caption := OpenDialog.FileName;
    end;
  end;

procedure TMainForm.FileSave(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do begin
    if Caption = '[untitled]' then
      FileSaveAs(Sender)
    else
      Memo.Lines.SaveToFile(Caption);
  end;
end;

procedure TMainForm.FileSaveAs(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  if SaveDialog.Execute then
  begin
    (ActiveMDIChild as TChildForm).Caption := SaveDialog.FileName;
    FileSave(Sender);
  end;
end;

procedure TMainForm.FileExit(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.EditUndo(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.Perform(WM_UNDO, 0, 0);
end;

procedure TMainForm.EditCut(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.CutToClipboard;
end;

procedure TMainForm.EditCopy(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.CopyToClipboard
end;

procedure TMainForm.EditPaste(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.PasteFromClipboard;
end;

procedure TMainForm.WindowTile(Sender: TObject);
begin
  Tile;
end;

procedure TMainForm.WindowCascade(Sender: TObject);
begin
  Cascade;
end;

procedure TMainForm.WindowArrange(Sender: TObject);
begin
  ArrangeIcons;
end;

procedure TMainForm.MRUFileListMRUItemClick(Sender: TObject; AFilename: string);
begin
  with TChildForm.Create(Self) do begin
    Memo.Lines.LoadFromFile(AFileName);
    Caption := AFileName;
  end;
end;

end.
